@@ -5,7 +5,7 @@ use Mojo::UserAgent;
 use Mojolicious::Plugin::LinkEmbedder::Link;
 use constant DEBUG => $ENV{MOJO_LINKEMBEDDER_DEBUG} || 0;
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 has _ua => sub { Mojo::UserAgent->new(max_redirects => 3) };
 
@@ -111,7 +111,7 @@ sub register {
     'gist.github'    => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::GistGithub',
     'github'         => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::Github',
     'html'           => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::HTML',
-    'instagram'    => 'Mojolicious::Plugin::LinkEmbedder::Link::Image::Instagram',
+    'instagram'      => 'Mojolicious::Plugin::LinkEmbedder::Link::Image::Instagram',
     'image'          => 'Mojolicious::Plugin::LinkEmbedder::Link::Image',
     'imgur'          => 'Mojolicious::Plugin::LinkEmbedder::Link::Image::Imgur',
     'ix'             => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::Ix',
@@ -188,167 +188,15 @@ sub _add_action {
 
 =head1 NAME
 
-Mojolicious::Plugin::LinkEmbedder - Convert a URL to embedded content
+Mojolicious::Plugin::LinkEmbedder - Deprecated
 
 =head1 VERSION
 
-0.24
+0.25
 
 =head1 DESCRIPTION
 
-This module can transform a URL to an iframe, image or other embeddable
-content.
-
-=head1 SYNOPSIS
-
-=head2 Simple version
-
-  use Mojolicious::Lite;
-  plugin LinkEmbedder => { route => '/embed' };
-
-=head2 Full control
-
-  plugin 'LinkEmbedder';
-
-  get '/embed' => sub {
-    my $c = shift;
-
-    $c->delay(
-      sub {
-        my ($delay) = @_;
-        $c->embed_link($c->param('url'), $delay->begin);
-      },
-      sub {
-        my ($delay, $link) = @_;
-
-        $c->respond_to(
-          json => {
-            json => {
-              media_id => $link->media_id,
-              url => $link->url->to_string,
-            },
-          },
-          any => { text => $link->to_embed }
-        );
-      }
-    );
-  };
-
-=head2 Example with caching
-
-  plugin 'LinkEmbedder';
-
-  get '/embed' => sub {
-    my $c = shift;
-    my $url = $c->param('url');
-    my $cached;
-
-    $c->delay(
-      sub {
-        my ($delay) = @_;
-        return $delay->pass($cached) if $cached = $c->cache->get($url);
-        return $c->embed_link($c->param('url'), $delay->begin);
-      },
-      sub {
-        my ($delay, $link) = @_;
-
-        $link = $link->TO_JSON if UNIVERSAL::can($link, 'TO_JSON');
-        $c->cache->set($url => $link);
-
-        $c->respond_to(
-          json => {
-            json => {
-              media_id => $link->{media_id},
-              url => $link->{url},
-            },
-          },
-          any => { text => $link->{html} }
-        );
-      }
-    );
-  };
-
-=head1 SUPPORTED LINKS
-
-=over 4
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Game::_2play>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Image>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Image::Imgur>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Image::Instagram>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Image::Xkcd>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Music::Spotify>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::AppearIn>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::Dbtv>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::Collegehumor>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::Dagbladet>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::Ted>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::Vimeo>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::Youtube>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::HTML>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Github>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::GistGithub>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Ix>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Metacpan>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Pastebin>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Pastie>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::PasteScsysCoUk>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Twitter>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Travis>
-
-=back
-
-=head1 METHODS
-
-=head2 embed_link
-
-See L</SYNOPSIS>.
-
-=head2 register
-
-  $app->plugin('LinkEmbedder' => \%config);
-
-Will register the L</embed_link> helper which creates new objects from
-L<Mojolicious::Plugin::LinkEmbedder::Default>. C<%config> is optional but can
-contain:
-
-=over 4
-
-=item * route => $str|$obj
-
-Use this if you want to have the default handler to do link embedding.
-The default handler is shown in L</SYNOPSIS>. C<$str> is just a path,
-while C<$obj> is a L<Mojolicious::Routes::Route> object.
-
-=back
+Deprecated in favor of L<LinkEmbedder>
 
 =head1 DISCLAIMER
 
