@@ -36,39 +36,3 @@ sub to_embed {
 }
 
 1;
-
-=encoding utf8
-
-=head1 NAME
-
-Mojolicious::Plugin::LinkEmbedder::Link::Map::Google - maps.google.com link
-
-=head1 DESCRIPTION
-
-This class inherit from L<Mojolicious::Plugin::LinkEmbedder::Link>.
-
-=head1 ATTRIBUTES
-
-=head2 media_id
-
-=head2 provider_name
-
-"Google".
-
-=head1 METHODS
-
-=head2 learn
-
-=head2 pretty_url
-
-Returns L</url> without "eurl", "mode" and "search" query params.
-
-=head2 to_embed
-
-Returns the HTML code for an iframe embedding this movie.
-
-=head1 SEE ALSO
-
-L<Mojolicious::Plugin::LinkEmbedder>.
-
-=cut
