@@ -41,41 +41,3 @@ sub to_embed {
 }
 
 1;
-
-=encoding utf8
-
-=head1 NAME
-
-Mojolicious::Plugin::LinkEmbedder::Link::Music::Spotify - Spotify link
-
-=head1 DESCRIPTION
-
-L<https://developer.spotify.com/technologies/widgets/spotify-play-button/>
-
-This class inherit from L<Mojolicious::Plugin::LinkEmbedder::Link::Music>.
-
-=head1 ATTRIBUTES
-
-=head2 media_id
-
-Returns a normalized spotify link.
-
-=head2 provider_name
-
-Returns "Spotify".
-
-=head1 METHODS
-
-=head2 pretty_url
-
-Returns a L<https://open.spotify.com> link with L</media_id>.
-
-=head2 to_embed
-
-Returns the HTML code for an iframe embedding this movie.
-
-=head1 AUTHOR
-
-Marcus Ramberg
-
-=cut
