@@ -37,35 +37,3 @@ sub to_embed {
 }
 
 1;
-
-=encoding utf8
-
-=head1 NAME
-
-Mojolicious::Plugin::LinkEmbedder::Link::Text::Twitter - twitter.com link
-
-=head1 DESCRIPTION
-
-This class inherit from L<Mojolicious::Plugin::LinkEmbedder::Link::Text>.
-
-=head1 ATTRIBUTES
-
-=head2 media_id
-
-  $str = $self->media_id;
-
-Example C<$str>: "/username/status/123456789".
-
-=head2 provider_name
-
-=head1 METHODS
-
-=head2 to_embed
-
-Returns the HTML code for javascript embedding this tweet.
-
-=head1 AUTHOR
-
-Jan Henning Thorsen
-
-=cut
