@@ -34,35 +34,3 @@ sub to_embed {
 }
 
 1;
-
-=encoding utf8
-
-=head1 NAME
-
-Mojolicious::Plugin::LinkEmbedder::Link::Video::Vimeo - vimeo.com video
-
-=head1 DESCRIPTION
-
-This class inherit from L<Mojolicious::Plugin::LinkEmbedder::Link::Text::HTML>.
-
-=head1 ATTRIBUTES
-
-=head2 media_id
-
-Returns the the digit from the url L</url>.
-
-=head2 provider_name
-
-=head1 METHODS
-
-=head2 learn
-
-=head2 to_embed
-
-Returns the HTML code for an iframe embedding this movie.
-
-=head1 AUTHOR
-
-Marcus Ramberg
-
-=cut
