@@ -43,41 +43,3 @@ sub to_embed {
 }
 
 1;
-
-=encoding utf8
-
-=head1 NAME
-
-Mojolicious::Plugin::LinkEmbedder::Link::Video::Youtube - youtube.com link
-
-=head1 DESCRIPTION
-
-L<https://developers.google.com/youtube/player_parameters#Embedding_a_Player>
-
-This class inherit from L<Mojolicious::Plugin::LinkEmbedder::Link::Text::HTML>.
-
-=head1 ATTRIBUTES
-
-=head2 media_id
-
-Returns the "v" query param value from L</url>.
-
-=head2 provider_name
-
-=head1 METHODS
-
-=head2 learn
-
-=head2 pretty_url
-
-Returns L</url> without "eurl", "mode" and "search" query params.
-
-=head2 to_embed
-
-Returns the HTML code for an iframe embedding this movie.
-
-=head1 AUTHOR
-
-Marcus Ramberg
-
-=cut
